==> haskell-kan-extensions-5.2.6-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.6
visibility:           public
id:                   kan-extensions-5.2.6-Ahb4RzozToDKA1yoLbRRNE
key:                  kan-extensions-5.2.6-Ahb4RzozToDKA1yoLbRRNE
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  6fed953dcd98f249f88e49800a85eeed
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.6-Ahb4RzozToDKA1yoLbRRNE
depends:
    adjunctions-4.4.3-9Ui96ZDRixDJLNc8PSBbxp array-0.5.4.0
    base-4.17.2.1 comonad-5.0.9-H8oocmDV4D4EXW6X9QEulT containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-2RG4pNqBbPl8HqIwteKJTh
    free-5.2-56nV52ZelcOG72yz0HBeFg
    invariant-0.6.3-GhkL2PRjjfxK4u0CnQBcdq mtl-2.2.2
    profunctors-5.6.2-3t5vu9jgXwLFYMLBE35bzQ
    semigroupoids-6.0.1-19ciehZXBAfDCUXqtOB88G
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2.6-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.6
visibility:           public
id:                   kan-extensions-5.2.6-6Q7sMSLJydX3ExsNuXy3pI
key:                  kan-extensions-5.2.6-6Q7sMSLJydX3ExsNuXy3pI
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  f470e2932cd960fd7eaad620fb3e351f
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kan-extensions-5.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.6-6Q7sMSLJydX3ExsNuXy3pI
depends:
    adjunctions-4.4.3-8dQyARkhnbn6EiLhw5uZ7j array-0.5.4.0
    base-4.17.2.1 comonad-5.0.9-9Yo0F70vMsQCliBu5JmVpZ containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-FOMMZr6IeKaFu6RVW4eVJm
    free-5.2-LTQciI5FbffBtUCNsKjF13
    invariant-0.6.3-9SAQfwqa6flGVhSDwFBxw0 mtl-2.2.2
    profunctors-5.6.2-FLsdp2O4vU5EVB9f4TrRaL
    semigroupoids-6.0.1-F8Zr6XW5vm7BOWrjGfl0On
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
